==> estateplat-common-1.2.4-20201113.014416-502-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/ZttGyQlrBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.ZttGyQlr;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class ZttGyQlrBdc extends ZttGyQlr {
    private String dfsshydm;
    private String dfsshymc;
    private String dfhjszssdm;
    private String dfhjszssmc;
    private String dfxbdm;
    private String dfxbmc;
    private String dfgyfsdm;
    private String dfgyfsmc;


    @XmlAttribute(
            name = "DFSSHYDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfsshydm() {
        return dfsshydm;
    }

    public void setDfsshydm(String dfsshydm) {
        this.dfsshydm = dfsshydm;
    }
    @XmlAttribute(
            name = "DFSSHYMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfsshymc() {
        return dfsshymc;
    }

    public void setDfsshymc(String dfsshymc) {
        this.dfsshymc = dfsshymc;
    }
    @XmlAttribute(
            name = "DFHJSZSSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfhjszssdm() {
        return dfhjszssdm;
    }

    public void setDfhjszssdm(String dfhjszssdm) {
        this.dfhjszssdm = dfhjszssdm;
    }
    @XmlAttribute(
            name = "DFHJSZSSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfhjszssmc() {
        return dfhjszssmc;
    }

    public void setDfhjszssmc(String dfhjszssmc) {
        this.dfhjszssmc = dfhjszssmc;
    }
    @XmlAttribute(
            name = "DFXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfxbdm() {
        return dfxbdm;
    }

    public void setDfxbdm(String dfxbdm) {
        this.dfxbdm = dfxbdm;
    }
    @XmlAttribute(
            name = "DFXBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfxbmc() {
        return dfxbmc;
    }

    public void setDfxbmc(String dfxbmc) {
        this.dfxbmc = dfxbmc;
    }
    @XmlAttribute(
            name = "DFGYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfgyfsdm() {
        return dfgyfsdm;
    }

    public void setDfgyfsdm(String dfgyfsdm) {
        this.dfgyfsdm = dfgyfsdm;
    }
    @XmlAttribute(
            name = "DFGYFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfgyfsmc() {
        return dfgyfsmc;
    }

    public void setDfgyfsmc(String dfgyfsmc) {
        this.dfgyfsmc = dfgyfsmc;
    }
}

==> estateplat-common-1.2.4-20201116.060719-507-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/ZttGyQlrBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.ZttGyQlr;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class ZttGyQlrBdc extends ZttGyQlr {
    private String dfsshydm;
    private String dfsshymc;
    private String dfhjszssdm;
    private String dfhjszssmc;
    private String dfxbdm;
    private String dfxbmc;
    private String dfgyfsdm;
    private String dfgyfsmc;


    @XmlAttribute(
            name = "DFSSHYDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsshydm() {
        return dfsshydm;
    }

    public void setDfsshydm(String dfsshydm) {
        this.dfsshydm = dfsshydm;
    }
    @XmlAttribute(
            name = "DFSSHYMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsshymc() {
        return dfsshymc;
    }

    public void setDfsshymc(String dfsshymc) {
        this.dfsshymc = dfsshymc;
    }
    @XmlAttribute(
            name = "DFHJSZSSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhjszssdm() {
        return dfhjszssdm;
    }

    public void setDfhjszssdm(String dfhjszssdm) {
        this.dfhjszssdm = dfhjszssdm;
    }
    @XmlAttribute(
            name = "DFHJSZSSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhjszssmc() {
        return dfhjszssmc;
    }

    public void setDfhjszssmc(String dfhjszssmc) {
        this.dfhjszssmc = dfhjszssmc;
    }
    @XmlAttribute(
            name = "DFXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxbdm() {
        return dfxbdm;
    }

    public void setDfxbdm(String dfxbdm) {
        this.dfxbdm = dfxbdm;
    }
    @XmlAttribute(
            name = "DFXBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxbmc() {
        return dfxbmc;
    }

    public void setDfxbmc(String dfxbmc) {
        this.dfxbmc = dfxbmc;
    }
    @XmlAttribute(
            name = "DFGYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgyfsdm() {
        return dfgyfsdm;
    }

    public void setDfgyfsdm(String dfgyfsdm) {
        this.dfgyfsdm = dfgyfsdm;
    }
    @XmlAttribute(
            name = "DFGYFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgyfsmc() {
        return dfgyfsmc;
    }

    public void setDfgyfsmc(String dfgyfsmc) {
        this.dfgyfsmc = dfgyfsmc;
    }
}
